@@ -4,6 +4,7 @@ import cPickle
 
 from mox import MoxTestBase, IsA
 import gevent
+
 from boto.s3.bucket import Bucket
 from boto.s3.key import Key
 from boto.sqs.queue import Queue
@@ -27,11 +28,12 @@ class TestSimpleStorageService(MoxTestBase):
     def test_write_message(self):
         self.s3.Key.__call__(self.bucket).AndReturn(self.key)
         self.key.set_metadata('timestamp', '1234.0')
-        self.key.set_metadata('attempts', '0')
+        self.key.set_metadata('attempts', '')
+        self.key.set_metadata('delivered_indexes', '')
         self.key.set_contents_from_string(self.pickled_env)
         self.mox.ReplayAll()
         self.s3.write_message(self.env, 1234.0)
-        self.assertIsInstance(self.key.key, basestring)
+        self.assertTrue(isinstance(self.key.key, basestring))
         self.assertTrue(self.key.key.startswith('test-'))
 
     def test_set_message_meta(self):
@@ -52,21 +54,25 @@ class TestSimpleStorageService(MoxTestBase):
         self.key.get_contents_as_string().AndReturn(self.pickled_env)
         self.key.get_metadata('timestamp').AndReturn('4321.0')
         self.key.get_metadata('attempts').AndReturn('5')
+        self.key.get_metadata('delivered_indexes').AndReturn('')
         self.mox.ReplayAll()
-        env, timestamp, attempts = self.s3.get_message('storeid')
+        env, meta = self.s3.get_message('storeid')
         self.assertEqual('sender@example.com', env.sender)
         self.assertEqual(['rcpt@example.com'], env.recipients)
-        self.assertEqual(4321.0, timestamp)
-        self.assertEqual(5, attempts)
+        self.assertEqual(4321.0, meta['timestamp'])
+        self.assertEqual(5, meta['attempts'])
+        self.assertFalse('delivered_indexes' in meta)
 
     def test_get_message_meta(self):
         self.bucket.get_key('storeid').AndReturn(self.key)
         self.key.get_metadata('timestamp').AndReturn('4321.0')
         self.key.get_metadata('attempts').AndReturn('5')
+        self.key.get_metadata('delivered_indexes').AndReturn('[1, 2]')
         self.mox.ReplayAll()
-        timestamp, attempts = self.s3.get_message_meta('storeid')
-        self.assertEqual(4321.0, timestamp)
-        self.assertEqual(5, attempts)
+        meta = self.s3.get_message_meta('storeid')
+        self.assertEqual(4321.0, meta['timestamp'])
+        self.assertEqual(5, meta['attempts'])
+        self.assertEqual([1, 2], meta['delivered_indexes'])
 
     def test_list_messages(self):
         self.mox.StubOutWithMock(self.s3, 'get_message_meta')
