@@ -35,7 +35,6 @@ class TestRackspaceCloudFiles(MoxTestBase):
         conn.putheader('Content-Type', 'application/octet-stream')
         conn.putheader('Content-Length', str(len(self.pickled_env)))
         conn.putheader('X-Object-Meta-Timestamp', '1234.0')
-        conn.putheader('X-Object-Meta-Attempts', '0')
         conn.putheader('X-Auth-Token', 'tokenid')
         conn.endheaders(self.pickled_env)
         conn.getresponse().AndReturn(res)
@@ -97,14 +96,16 @@ class TestRackspaceCloudFiles(MoxTestBase):
         res.getheaders().AndReturn([])
         res.read().AndReturn(self.pickled_env)
         res.getheader('X-Object-Meta-Timestamp').AndReturn('1234.0')
-        res.getheader('X-Object-Meta-Attempts').AndReturn('3')
+        res.getheader('X-Object-Meta-Attempts', None).AndReturn('3')
+        res.getheader('X-Object-Meta-Delivered-Rcpts', None).AndReturn('[1, 2]')
         self.mox.ReplayAll()
-        env, timestamp, attempts = files.get_message('4321')
-        self.assertIsInstance(env, Envelope)
+        env, meta = files.get_message('4321')
+        self.assertTrue(isinstance(env, Envelope))
         self.assertEqual('sender@example.com', env.sender)
         self.assertEqual(['rcpt@example.com'], env.recipients)
-        self.assertEqual(1234.0, timestamp)
-        self.assertEqual(3, attempts)
+        self.assertEqual(1234.0, meta['timestamp'])
+        self.assertEqual(3, meta['attempts'])
+        self.assertEqual([1, 2], meta['delivered_indexes'])
 
     def test_get_message_meta(self):
         files = RackspaceCloudFiles(self.auth, container='test')
@@ -121,11 +122,13 @@ class TestRackspaceCloudFiles(MoxTestBase):
         res.reason = 'OK'
         res.getheaders().AndReturn([])
         res.getheader('X-Object-Meta-Timestamp').AndReturn('1234.0')
-        res.getheader('X-Object-Meta-Attempts').AndReturn('3')
+        res.getheader('X-Object-Meta-Attempts', None).AndReturn('3')
+        res.getheader('X-Object-Meta-Delivered-Rcpts', None).AndReturn(None)
         self.mox.ReplayAll()
-        timestamp, attempts = files.get_message_meta('4321')
-        self.assertEqual(1234.0, timestamp)
-        self.assertEqual(3, attempts)
+        meta = files.get_message_meta('4321')
+        self.assertEqual(1234.0, meta['timestamp'])
+        self.assertEqual(3, meta['attempts'])
+        self.assertFalse('delivered_indexes' in meta)
 
     def test_list_messages_page(self):
         files = RackspaceCloudFiles(self.auth, container='test', prefix='test-')
